==> react-components-library-0.0.21.tgz: package/src/Form/Range/index.tsx <==
import React from "react";
import PropTypes from "prop-types";
import { ProgressBar } from "../../ProgressBar";
import { FormElement } from "../formElement";
import { Tracker } from "./tracker";
import { Scope, useStyle } from "../../Scope";
import styling from "@devcake/styling";
import { Color, ColorPropType } from "../../types";

styling.setDefault("components.rangeinput.text.container", "mt-1");
styling.setDefault("components.rangeinput.text.text", "text-sm");
styling.setDefault("components.rangeinput.text.left", "");
styling.setDefault("components.rangeinput.text.center", "-ml-4 w-8 text-center");
styling.setDefault("components.rangeinput.text.right", "");

export type RangeInputProps = FormElement<number> & {
  color?: Color;
  hideLabels?: number;
  max?: number;
  min?: number;
  render?: (value: number) => string;
}

export const RangeInput: React.FunctionComponent<RangeInputProps> = ({
                                                                       color,
                                                                       hideLabels,
                                                                       max,
                                                                       min,
                                                                       onChange,
                                                                       render,
                                                                       value
                                                                     }) => {
  const ref = React.createRef<HTMLDivElement>();
  const [innerValue, setInnerValue] = React.useState(0.5);
  const [tracking, setTracking] = React.useState(false);

  const width = max - min;

  React.useEffect(() => {
    if (isNaN(value)) return;
    setInnerValue((value - min) / (width));
  }, [width, value]);

  const update = event => {
    if (event.type === "mousemove" && !tracking) return;
    const pageOffset = event.clientX;
    const rect = ref.current.getBoundingClientRect();
    const elementOffset = pageOffset - rect.left;
    let value = elementOffset / ref.current.clientWidth;
    if (value > 1) value = 1;
    else if (value < 0) value = 0;
    setInnerValue(value);
    if (onChange) onChange(value);
  };

  const [container, text, left, center, right] = useStyle(["container", "text", "left", "center", "right"], "components.rangeinput.text");

  return (
    <Scope overrides={{ "selected": "absolute h-4 inline-block rounded-full" }} scope="components.progress">
      <ProgressBar
        color={color}
        current={innerValue}
        onClick={update}
        onMouseDown={() => setTracking(true)}
        onMouseEnter={evt => evt.buttons % 2 === 1 && setTracking(true)}
        onMouseLeave={() => setTracking(false)}
        onMouseMove={update}
        onMouseUp={() => setTracking(false)}
        ref={ref}
        tracker={<Tracker />}
      />
      <div className={`relative ${container}`}>
        <div className={`absolute left-0 ${left} ${text} ${innerValue < hideLabels ? "hidden" : ""}`}>
          {render(min)}
        </div>
        <div className={`absolute ${center} ${text}`} style={{ left: `${innerValue * 100}%` }}>
          {render(innerValue * width + min)}
        </div>
        <div className={`absolute right-0 ${right} ${text} ${innerValue > 1 - hideLabels ? "hidden" : ""}`}>
          {render(max)}
        </div>
      </div>
    </Scope>
  );
};
RangeInput.propTypes = {
  color: ColorPropType,
  hideLabels: PropTypes.number,
  max: PropTypes.number,
  min: PropTypes.number,
  onChange: PropTypes.func,
  render: PropTypes.func,
  value: PropTypes.number
};
RangeInput.defaultProps = {
  color: "blue",
  hideLabels: 0.05,
  max: 1,
  min: 0,
  render: v => v.toFixed(2)
};

==> react-components-library-0.0.27.tgz: package/src/Form/Range/index.tsx <==
import React from "react";
import PropTypes from "prop-types";
import { ProgressBar } from "../../ProgressBar";
import { FormElement } from "../formElement";
import { Tracker } from "./tracker";
import { Scope, useStyle } from "../../Scope";
import styling from "@devcake/styling";
import { Color, ColorPropType } from "../../types";

styling.setDefault("components.rangeinput.text.container", "mt-1");
styling.setDefault("components.rangeinput.text.text", "text-sm");
styling.setDefault("components.rangeinput.text.left", "");
styling.setDefault("components.rangeinput.text.center", "-ml-4 w-8 text-center");
styling.setDefault("components.rangeinput.text.right", "");

export type RangeInputProps = FormElement<number> & {
  color?: Color;
  hideLabels?: number;
  max?: number;
  min?: number;
  render?: (value: number) => string;
}

export const RangeInput: React.FunctionComponent<RangeInputProps> = ({
                                                                       color,
                                                                       hideLabels,
                                                                       max,
                                                                       min,
                                                                       onChange,
                                                                       render,
                                                                       value
                                                                     }) => {
  const ref = React.createRef<HTMLDivElement>();
  const [innerValue, setInnerValue] = React.useState(0.5);
  const [tracking, setTracking] = React.useState(false);

  const width = max - min;

  React.useEffect(() => {
    if (isNaN(value)) return;
    setInnerValue((value - min) / (width));
  }, [width, value]);

  const update = event => {
    if (event.type === "mousemove" && !tracking) return;
    const pageOffset = event.clientX;
    const rect = ref.current.getBoundingClientRect();
    const elementOffset = pageOffset - rect.left;
    let value = elementOffset / ref.current.clientWidth;
    if (value > 1) value = 1;
    else if (value < 0) value = 0;
    setInnerValue(value);
    if (onChange) onChange(value * width + min);
  };

  const [container, text, left, center, right] = useStyle(["container", "text", "left", "center", "right"], "components.rangeinput.text");

  return (
    <Scope overrides={{ "selected": "absolute h-4 inline-block rounded-full" }} scope="components.progress">
      <ProgressBar
        color={color}
        current={innerValue}
        onClick={update}
        onMouseDown={() => setTracking(true)}
        onMouseEnter={evt => evt.buttons % 2 === 1 && setTracking(true)}
        onMouseLeave={() => setTracking(false)}
        onMouseMove={update}
        onMouseUp={() => setTracking(false)}
        ref={ref}
        tracker={<Tracker />}
      />
      <div className={`relative ${container}`}>
        <div className={`absolute left-0 ${left} ${text} ${innerValue < hideLabels ? "hidden" : ""}`}>
          {render(min)}
        </div>
        <div className={`absolute ${center} ${text}`} style={{ left: `${innerValue * 100}%` }}>
          {render(innerValue * width + min)}
        </div>
        <div className={`absolute right-0 ${right} ${text} ${innerValue > 1 - hideLabels ? "hidden" : ""}`}>
          {render(max)}
        </div>
      </div>
    </Scope>
  );
};
RangeInput.propTypes = {
  color: ColorPropType,
  hideLabels: PropTypes.number,
  max: PropTypes.number,
  min: PropTypes.number,
  onChange: PropTypes.func,
  render: PropTypes.func,
  value: PropTypes.number
};
RangeInput.defaultProps = {
  color: "blue",
  hideLabels: 0.05,
  max: 1,
  min: 0,
  render: v => v.toFixed(2)
};
